﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Dades;
using System.Windows;
using System.Windows.Forms;

namespace Negoci
{
    // Classe que agrupa la lògica de l'aplicació relativa a les operacions amb clients.
    public class Client
    {
        // Establim la connexió amb les classes que modelitzen la BD.
        DataClassesDataContext db = new DataClassesDataContext();

        // Mètode que retorna el llistat dels clients registrats al sistema.
        public List<Client_Registrat> LlistaClients()
        {     
            try
            {
                var query = (from c in db.Client_Registrat
                            orderby c.nom, c.cognom1, c.cognom2 ascending
                            select c).ToList();
                return query;
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }                
        }

        // Mètode que retorna el llistat dels clients que han rebut una oferta determinada.
        public List<Client_Registrat> LlistaClientsOferta(string idOferta)
        {   
            try
            {
                 var query = (from c in db.Client_Registrat
                              join of in db.Oferta_Client on c.DNI equals of.DNI
                              where of.idOferta.Equals(idOferta)                            
                              select c).ToList();
                 return query;                       
             }
             catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }         
        }

        //Mètode que permet obtenir un client registrat al sistema a partir del seu DNI.
        public Client_Registrat GetClient(int DNI)
        {
            try
            {
                var query = (from c in db.Client_Registrat
                             where c.DNI == DNI
                             select c).FirstOrDefault();
                return query;
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }         
        }
    }
}
