﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Dades;
using System.Windows;
using System.Windows.Data;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Forms;

namespace Negoci
{
    // Classe que agrupa la lògica de l'aplicació relativa a les operacions amb consumicions.
    public class Consumicio
    {
        // Establim la connexió amb les classes que modelitzen la BD.
        DataClassesDataContext db = new DataClassesDataContext();

        // Mètode que recupera una consumició de la BD a partir del nom
        public Consumicions GetConsumicio(string nom)
        {
            try
            {
                var query = (from c in db.Consumicions
                           where c.nomConsumicioCatala.Equals(nom)
                           select c).FirstOrDefault();
                return query;
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }
        }

        // Mètode que retorna un llistat amb les seccions.
        public List<Seccions> LlistaSeccions()
        {            
            try
            {
                var query = (from s in db.Seccions
                             orderby s.nomSeccio, s.nomSeccio ascending
                             select s).ToList();
                return query;                  
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }          
        }
        
        // Mètode que retorna un llistat amb les consumicions del sistema que són primers plats.
        public List<Consumicions> LlistaPrimers()
        {             
            try
            {                    
                var query = (from p in db.Consumicions
                          // Considerem primers plats només alguns tipus de plats.
                          where (p.nomSeccio.Equals("Entrants")||p.nomSeccio.Equals("Amanides i Sopes")||p.nomSeccio.Equals("Pasta i Arrossos"))
                          orderby p.nomConsumicioCatala, p.nomConsumicioCatala ascending                               
                          select p).ToList();
                return query;
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }         
        }

        // Mètode que retorna un llistat amb les consumicions del sistema que són segons plats.
        public List<Consumicions> LlistaSegons()
        {           
            try
            {
                var query = (from p in db.Consumicions
                            // Considerem segons plats només alguns tipus de plats.
                            where (p.nomSeccio.Equals("Carns") || p.nomSeccio.Equals("Peix i Marisc"))
                            orderby p.nomConsumicioCatala, p.nomConsumicioCatala ascending                              
                            select p).ToList();
                return query;
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }        
        }

        // Mètode que retorna un llistat amb els postres.
        public List<Consumicions> LlistaPostres()
        {  
             try
             {
                var query = (from p in db.Consumicions                              
                            where p.nomSeccio.Equals("Postres")
                            orderby p.nomConsumicioCatala, p.nomConsumicioCatala ascending                              
                            select p).ToList();
                return query;
             }
             catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }          
        }

        // Mètode que retorna un llistat amb les begudes.
        public List<Consumicions> LlistaBegudes()
        {
             try
             {
                 var query = (from p in db.Consumicions
                             where p.nomSeccio.Equals("Begudes")
                             orderby p.nomConsumicioCatala, p.nomConsumicioCatala ascending
                             select p).ToList();
                 return query;
             }
             catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }           
        }

        // Mètode que retorna un llistat amb totes les consumicions.
        public List<Consumicions> LlistaConsumicions()
        { 
             try
             {
                  var query = (from p in db.Consumicions
                              orderby p.nomConsumicioCatala, p.nomConsumicioCatala ascending
                              select p).ToList();
                  return query;
             }
             catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }                   
        }

        // Mètode que permet afegir una nova consumició al sistema.
        public void AfegirConsumicio(string nomCatala, string nomCastella, string nomAngles, string seccio, int comensals, float preu, string comentaris)
        {
            try
            {
                Consumicions c = new Consumicions();

                c.nomConsumicioCatala = nomCatala;
                c.nomConsumicioCastella = nomCastella;
                c.nomConsumicioAngles = nomAngles;
                c.nomSeccio = seccio;
                c.minComensals = comensals;
                c.preu = preu;
                c.descripcio = comentaris;

                // Insereix una nova consumició quan es fan el canvis
                db.Consumicions.InsertOnSubmit(c);

                // Es fan els canvis
                db.SubmitChanges();

                // Tanquem la conexio
                db.Connection.Close();
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); }                   
        }
        
        // Mètode que permet esborrar una consumició identificada pel seu nom del sistema.
        public void EsborrarConsumicio(string nomCatala)
        {
            try
            {
                // Esborrem de la BD la consumició volguda
                var query = (from c in db.Consumicions
                           where c.nomConsumicioCatala == nomCatala
                           select c).FirstOrDefault();

                db.Consumicions.DeleteOnSubmit(query);

                db.SubmitChanges();

                // Esborrem les associacions de la consumició als diferents menús.
                var query2 = from csm in db.Consumicio_Seccio_Menu
                             where csm.nomConsumicioCatala == nomCatala
                             select csm;

                db.Consumicio_Seccio_Menu.DeleteAllOnSubmit(query2);

                db.SubmitChanges();
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); }                   
        }

        // Mètode que permet esborrar una consumició sense desfer les associacions amb els menús.
        public void ActualitzarConsumicio(string nomCatala)
        {
            try
            {
                var query = (from c in db.Consumicions
                           where c.nomConsumicioCatala == nomCatala
                           select c).FirstOrDefault();

                db.Consumicions.DeleteOnSubmit(query);                

                db.SubmitChanges();
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); }                   
        }   
    }
}
