﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Dades;
using System.Windows.Forms;

namespace Negoci
{
    // Classe que agrupa la lògica de l'aplicació relativa a les operacions amb menús.
    public class Menu
    {
        // Establim la connexió amb les classes que modelitzen la BD.
        DataClassesDataContext db = new DataClassesDataContext();

        // Mètode que retorna el menú segons el seu identificador.
        public Menus GetMenu(string nom)
        {
            try
            {
                var query = (from q in db.Menus
                             where q.nomMenu.Equals(nom)
                             select q).FirstOrDefault();
                return query;
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null;}            
        }

        // Mètode que permet afegir un menú al sistema.
        public void AfegirMenu(string nom, float preu, bool incIVA, bool incBeguda, int comensals, string descripcio,
                         List<String> primers, List<String> segons, List<String> postres, List<String> begudes)
        {
            try
            {
                // Guardem el menú a la BD.
                Menus m = new Menus();

                m.nomMenu = nom;
                m.preu = preu;
                m.incIva = incIVA;
                m.incBeguda = incBeguda;
                m.minComensals = comensals;

                // Si un menu ordinari no té cap descripció, se'n afegeix una per tal que es mostri al web.
                if (nom.StartsWith("Menú") && (descripcio.Equals(string.Empty))) descripcio = nom; 
                
                m.descripcio = descripcio;

                db.Menus.InsertOnSubmit(m);

                db.SubmitChanges();

                // Guardem les consumicions de les diferents seccions.
                foreach (String c in primers)
                {
                    Consumicio_Seccio_Menu csm = new Consumicio_Seccio_Menu();
                    csm.nomMenu = nom;
                    csm.nomSeccio = "primers";
                    csm.nomConsumicioCatala = c;
                    db.Consumicio_Seccio_Menu.InsertOnSubmit(csm);
                    db.SubmitChanges();
                }

                foreach (String c in segons)
                {
                    Consumicio_Seccio_Menu csm = new Consumicio_Seccio_Menu();
                    csm.nomMenu = nom;
                    csm.nomSeccio = "segons";
                    csm.nomConsumicioCatala = c;
                    db.Consumicio_Seccio_Menu.InsertOnSubmit(csm);
                    db.SubmitChanges();
                }

                foreach (String c in postres)
                {
                    Consumicio_Seccio_Menu csm = new Consumicio_Seccio_Menu();
                    csm.nomMenu = nom;
                    csm.nomSeccio = "postres";
                    csm.nomConsumicioCatala = c;
                    db.Consumicio_Seccio_Menu.InsertOnSubmit(csm);
                    db.SubmitChanges();
                }

                foreach (String c in begudes)
                {
                    Consumicio_Seccio_Menu csm = new Consumicio_Seccio_Menu();
                    csm.nomMenu = nom;
                    csm.nomSeccio = "begudes";
                    csm.nomConsumicioCatala = c;
                    db.Consumicio_Seccio_Menu.InsertOnSubmit(csm);
                    db.SubmitChanges();
                }
                // Tanquem la conexio
                db.Connection.Close();
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); }                   
        }    

        // Mètode que retorna un llistat amb els menús del sistema.
        public List<Menus> LlistaMenus()
        {       
             try
             {
                 var query = (from m in db.Menus
                             orderby m.nomMenu, m.nomMenu ascending
                             select m).ToList();
                 return query;
             }
             catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }         
        }

        // Mètode que retorna un llistat amb els primers del menú donat.
         public List<Consumicio_Seccio_Menu> LlistaPrimersMenu(string nom)
         {
             try
             {
                 var query = (from csm in db.Consumicio_Seccio_Menu
                              where (csm.nomMenu == nom && csm.nomSeccio.Equals("Primers"))
                              select csm).ToList();
                 return query;
             }
             catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }         
         }

         // Mètode que retorna un llistat amb els segons del menú donat.
         public List<Consumicio_Seccio_Menu> LlistaSegonsMenu(string nom)
         {
             try
             {
                 var query = (from csm in db.Consumicio_Seccio_Menu
                              where (csm.nomMenu == nom && csm.nomSeccio.Equals("Segons"))
                              select csm).ToList();
                 return query;
             }
             catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }               
         }

         // Mètode que retorna un llistat amb els postres del menú donat.
         public List<Consumicio_Seccio_Menu> LlistaPostresMenu(string nom)
         {
             try
             {
                 var query = (from csm in db.Consumicio_Seccio_Menu
                              where (csm.nomMenu == nom && csm.nomSeccio.Equals("Postres"))
                              select csm).ToList();
                 return query;
             }
             catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }                           
         }

         // Mètode que retorna un llistat amb les begudes del menú donat.
         public List<Consumicio_Seccio_Menu> LlistaBegudesMenu(string nom)
         {
             try
             {
                 var query = (from csm in db.Consumicio_Seccio_Menu
                              where (csm.nomMenu == nom && csm.nomSeccio.Equals("Begudes"))
                              select csm).ToList();
                 return query;
             }
             catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }                                        
         }

        // Mètode que permet esborrar un menú de la BD segons el seu identificador.
         public void EsborrarMenu(string nom)
         {
             try
             {
                 // Esborrem el menú.
                 var query = (from m in db.Menus
                              where m.nomMenu == nom
                              select m).FirstOrDefault();

                 db.Menus.DeleteOnSubmit(query);

                 // Esborrem les consumicions del menú.
                 var query2 = from csm in db.Consumicio_Seccio_Menu
                              where csm.nomMenu == nom
                              select csm;

                 db.Consumicio_Seccio_Menu.DeleteAllOnSubmit(query2);

                 db.SubmitChanges();
             }
             catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); }                                        
         }         
    }
}
