﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Dades;
using System.Windows.Forms;

namespace Negoci
{
    // Classe que agrupa la lògica de l'aplicació relativa a les operacions amb ofertes.
    public class Oferta
    {
        // Establim la connexió amb les classes que modelitzen la BD.
        DataClassesDataContext db = new DataClassesDataContext();

        // Mètode que recupera una oferta de la BD a partir de l'identificador
        public Ofertes GetOferta(string id)
        {
            try
            {
                var query = (from c in db.Ofertes
                          where c.idOferta.Equals(id)
                          select c).FirstOrDefault();
                return query;
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }            
        }

        // Mètode que retorna el llistat de les ofertes enregistrades al sistema.
        public List<Ofertes> LlistaOfertes()
        {   
            try
            {
                 var query = (from p in db.Ofertes
                           orderby p.idOferta ascending
                           select p).ToList();
                 return query;
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }                        
        }

        // Mètode que permet afegir una oferta al sistema.
        public void AfegirOferta(string id, string descripcio, List<string> clients)
        {
            try
            {
                // Guardem l'oferta.
                Dades.Ofertes of = new Ofertes();

                of.idOferta = id;
                of.descripcio = descripcio;

                db.Ofertes.InsertOnSubmit(of);
                db.SubmitChanges();

                // Guardem els clients associats.
                foreach (string dni in clients)
                {
                    Dades.Oferta_Client ofc = new Oferta_Client();
                    ofc.idOferta = id;
                    ofc.DNI = int.Parse(dni);
                    db.Oferta_Client.InsertOnSubmit(ofc);
                    db.SubmitChanges();
                }

                db.Connection.Close();
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); }                        
        }

        // Mètode que permet esborrar una oferta del sistema segons el seu identificador.
        public void EsborrarOferta(string id)
        {
            try
            {
                // Esborrem la oferta.
                var query = (from of in db.Ofertes
                             where of.idOferta == id
                             select of).FirstOrDefault();

                db.Ofertes.DeleteOnSubmit(query);

                // Esborrem els clients associats.
                var query2 = from ofc in db.Oferta_Client
                             where ofc.idOferta == id
                             select ofc;

                db.Oferta_Client.DeleteAllOnSubmit(query2);

                db.SubmitChanges();

                db.Connection.Close();
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); }                        
        }
    }
}
