﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;
using Mòdul_Mòbil.ServiceReference;


namespace Mòdul_Mòbil
{
    public partial class AnotarComanda : PhoneApplicationPage
    {
        Comanda comanda;

        public AnotarComanda(Comanda com)
        {
            comanda = com;
            
            InitializeComponent();     
          
            ServiceReference.ServiceClient proxy = new ServiceReference.ServiceClient();
            
            // Carreguem el listbox que conté les consumicions demanades.
            proxy.LlistaComandesTaulaCompleted += new EventHandler<LlistaComandesTaulaCompletedEventArgs>(proxy_LlistaComandesTaulaCompleted);
            proxy.LlistaComandesTaulaAsync(comanda.taula);

            // Carreguem les dades de la comanda (taula, cambrer, hora)
            proxy.GetComandaCompleted += new EventHandler<GetComandaCompletedEventArgs>(proxy_GetComandaCompleted);
            proxy.GetComandaAsync(comanda.taula);
        }

        void proxy_GetComandaCompleted(object sender, GetComandaCompletedEventArgs e)
        {
            try
            {
                if (e != null)
                {
                    this.tbTaula.Text = e.Result.taula.ToString();
                    this.tbComensals.Text = e.Result.comensals.ToString();

                    this.tbHora.Text = e.Result.hora;
                }         
            }
            catch (FormatException ex) { MessageBox.Show(ex.Message, "Atenció!!", MessageBoxButton.OK); }
        }

        void proxy_LlistaComandesTaulaCompleted(object sender, LlistaComandesTaulaCompletedEventArgs e)
        {
            try
            {
                if (e != null)
                {
                    this.lbAnotarComandes.ItemsSource = e.Result.ToList();
                }             
            }
            catch (FormatException ex) { MessageBox.Show(ex.Message, "Atenció!!", MessageBoxButton.OK); }
        }

        // Si l'usuari vol afegir una comanda, naveguem a la pàgina pivot de les consumicions.
        private void Button_Click(object sender, RoutedEventArgs e)
        {
            App.Current.RootVisual = new PivotPlats(comanda); 
        }

        // Mètode que permet esborrar una unitat de la consumició seleccionada.
        private void botoDecUnitat_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                if (lbAnotarComandes.SelectedIndex != -1)
                {
                    string seleccio = ((Consumicio_Comanda)this.lbAnotarComandes.SelectedItem).comConsumicioCatala;

                    ServiceReference.ServiceClient proxy = new ServiceReference.ServiceClient();
                    proxy.EsborrarConsumicioComandaCompleted += new EventHandler<System.ComponentModel.AsyncCompletedEventArgs>(proxy_EsborrarConsumicioComandaCompleted);
                    proxy.EsborrarConsumicioComandaAsync(comanda.taula, seleccio);

                    MessageBox.Show("S'ha esborrat una unitat de " + seleccio, "Informació", MessageBoxButton.OK);
                }
            }
            catch (FormatException ex) { MessageBox.Show(ex.Message, "Atenció!!", MessageBoxButton.OK); }
        }

        // Mètode que permet marcar una unitat d'una comanda com a servida.
        private void botoServir_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                if (lbAnotarComandes.SelectedIndex != -1)
                {
                    string seleccio = ((Consumicio_Comanda)this.lbAnotarComandes.SelectedItem).comConsumicioCatala;

                    MessageBoxResult resposta = MessageBox.Show("Ha servit una unitat de " + seleccio + "?", "Pregunta", MessageBoxButton.OKCancel);

                    if (resposta == MessageBoxResult.OK)
                    {

                        ServiceReference.ServiceClient proxy = new ServiceReference.ServiceClient();
                        proxy.ServirConsumicioComandaCompleted += new EventHandler<System.ComponentModel.AsyncCompletedEventArgs>(proxy_ServirConsumicioComandaCompleted);
                        proxy.ServirConsumicioComandaAsync(comanda.taula, seleccio);
                    }

                    lbAnotarComandes.SelectedIndex = -1;
                }
            }
            catch (FormatException ex) { MessageBox.Show(ex.Message, "Atenció!!", MessageBoxButton.OK); }
        }

        private void botoTornarEditarComanda_Click(object sender, RoutedEventArgs e)
        {
            App.Current.RootVisual = new MenuPrincipal(comanda);
        }

        // Si l'usuari vol afegir un menu a la comanda, naveguem a la pàgina pivot dels menús.
        private void botoAfegirMenu_Click(object sender, RoutedEventArgs e)
        {
            App.Current.RootVisual = new PivotMenus(comanda);
        } 

        // Mètode que permet eafegir una unitat de la consumició seleccionada.
        private void botoIncUnitat_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                if (lbAnotarComandes.SelectedIndex != -1)
                {
                    string seleccio = ((Consumicio_Comanda)this.lbAnotarComandes.SelectedItem).comConsumicioCatala;

                    ServiceReference.ServiceClient proxy = new ServiceReference.ServiceClient();
                    proxy.GuardarConsumicioComandaCompleted += new EventHandler<System.ComponentModel.AsyncCompletedEventArgs>(proxy_GuardarConsumicioComandaCompleted);
                    proxy.GuardarConsumicioComandaAsync(comanda.taula, seleccio);

                    MessageBox.Show("S'ha afegit una unitat de " + seleccio, "Informació", MessageBoxButton.OK);
                }
            }
            catch (FormatException ex) { MessageBox.Show(ex.Message, "Atenció!!", MessageBoxButton.OK); }
        }

        // Quan es completa amb èxit l'operació refresquem la pàgina.
        void proxy_EsborrarConsumicioComandaCompleted(object sender, System.ComponentModel.AsyncCompletedEventArgs e)
        {           
            App.Current.RootVisual = new AnotarComanda(comanda);
        }

        void proxy_GuardarConsumicioComandaCompleted(object sender, System.ComponentModel.AsyncCompletedEventArgs e)
        {
            App.Current.RootVisual = new AnotarComanda(comanda);
        }

        void proxy_ServirConsumicioComandaCompleted(object sender, System.ComponentModel.AsyncCompletedEventArgs e)
        {
            App.Current.RootVisual = new AnotarComanda(comanda);
        }      
    }
}
