﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Dades;
using System.Windows;
using System.Windows.Forms;


namespace Negoci
{
    // Classe que agrupa la lògica de l'aplicació relativa a les operacions amb comandes.
    public class Comanda
    {
        // Establim la connexió amb les classes que modelitzen la BD.
        DataClassesDataContext db = new DataClassesDataContext();

        // Mètode que permet guardar una comanda a la BD.
        public void GuardarComanda(int taula, int comensals, int cambrer)
        {
            try
            {
                Dades.Comandes c = new Comandes();

                c.taula = taula;
                c.comensals = comensals;
                c.cambrer = cambrer;
                
                // La hora de la comanda és l'actual
                DateTime ara = new DateTime();                       
                ara = DateTime.Now;
                string horaComanda = ara.ToShortTimeString();
                                
                c.hora = horaComanda;

                // Inserim la comanda.
                db.Comandes.InsertOnSubmit(c);

                // Es fan els canvis.
                db.SubmitChanges();

                // Tanquem la connexió.
                db.Connection.Close();
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); }                        
        }

        // Mètode que permet guardar una consumició demanada com a part d'una comanda d'una taula.
        public void GuardarConsumicioComanda(int taula, string nomConsumicioCatala)
        {
            try
            {
                // Mirem si la comanda ja té una consumició d'aquest tipus
                Consumicio_Comanda consulta = this.ConsultarComanda(taula, nomConsumicioCatala);

                // La consulta és buida, creem una nova consumicio per a la comanda de zero.
                if (consulta == null)
                {
                    Dades.Consumicio_Comanda c = new Consumicio_Comanda();

                    c.idComanda = taula;
                    c.comConsumicioCatala = nomConsumicioCatala;
                    c.quantitat = 1;
                    c.quantitatServida = 0;

                    // Inserim la consumició.
                    db.Consumicio_Comanda.InsertOnSubmit(c);

                    // Es fan els canvis.
                    db.SubmitChanges();

                    // Tanquem la connexió.
                    db.Connection.Close();
                }

                // La consulta no és buida, actualitzem les dades.
                else
                {
                    consulta.quantitat++;                  

                    // Es fan els canvis.
                    db.SubmitChanges();

                    // Tanquem la connexió.
                    db.Connection.Close();
                }
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); }            
        }

        // Mètode que permet esborrar una consumició d'una comanda
        public void EsborrarConsumicioComanda(int taula, string nomConsumicioCatala)
        {
            try
            {
                // Mirem si la comanda és al sistema.
                Consumicio_Comanda consulta = this.ConsultarComanda(taula, nomConsumicioCatala);
             
                // Si existeix la comanda decrementem la quantitat o esborrem la consumició.
                if (consulta != null)
                {
                    if (consulta.quantitat > 1) 
                    {
                        if (consulta.quantitat == consulta.quantitatServida) { consulta.quantitatServida--; }
                        
                        consulta.quantitat--; 
                    }

                    else { db.Consumicio_Comanda.DeleteOnSubmit(consulta); }
                    
                    db.SubmitChanges();

                    db.Connection.Close();
                }
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); }            
        }

        // Mètode que permet esborrar una consumició d'una comanda
        public void ServirConsumicioComanda(int taula, string nomConsumicioCatala)
        {
            try
            {
                // Mirem si la comanda és al sistema.
                Consumicio_Comanda consulta = this.ConsultarComanda(taula, nomConsumicioCatala);

                // Si existeix la comanda servim una unitat sempre que la quantitat servida no sigui més gran que la demanada.
                if (consulta != null)
                {
                    if (consulta.quantitat > consulta.quantitatServida) { consulta.quantitatServida++; }                    

                    db.SubmitChanges();

                    db.Connection.Close();
                }
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); }
        }

        // Mètode que retorna les consumicions fetes per una taula.
        public List<Dades.Consumicio_Comanda> ConsumicionsComanda(int id)
        {
            try
            {
                var query = (from c in db.Consumicio_Comanda                           
                            where c.idComanda.Equals(id)
                            select c).ToList();

                db.Connection.Close();

                return query;                
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }         
        }

        // Mètode de consulta que permet saber si una taula té una comanda activa o no.
        public bool ConsultarTaula(int taula)
        {
            try
            {
                var query = (from c in db.Comandes
                             where c.taula.Equals(taula)
                             select c).FirstOrDefault();

                db.Connection.Close();

                if (query != null) return false;

                else return true;                
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return false; }         
        }

        // Mètode de consulta que retorna una consumició concreta d'una taula.
        public Consumicio_Comanda ConsultarComanda(int taula, string consumicio)
        {
            try
            {
                var query = (from c in db.Consumicio_Comanda
                             where c.idComanda.Equals(taula) && c.comConsumicioCatala.Equals(consumicio)
                             select c).FirstOrDefault();
                
                db.Connection.Close();
                
                return query;
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }         
        }

        // Mètode que permet tancar una comanda, és a dir esborrar-la del sistema juntament amb totes les dades associades.
        public void TancarComanda(int taula)
        {
            try
            {
                var query = (from c in db.Comandes
                             where c.taula.Equals(taula)
                             select c).FirstOrDefault();

                db.Comandes.DeleteOnSubmit(query);

                db.SubmitChanges();

                Boolean found = true;

                // Mentre hi hagi consumicions que formin part de la comanda les esborra.
                while (found)
                {
                    var query2 = (from cc in db.Consumicio_Comanda
                                  where cc.idComanda == taula
                                  select cc).FirstOrDefault();
                    if (query2 == null) found = false;
                    else
                    {
                        db.Consumicio_Comanda.DeleteOnSubmit(query2);

                        db.SubmitChanges();
                    }
                }
                db.Connection.Close();
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); }         
        }

        // Mètode de consulta que retorna una comanda feta per una taula.
        public Comandes GetComanda(int taula)
        {
            try
            {
                var query = (from c in db.Comandes
                             where c.taula.Equals(taula)
                             select c).FirstOrDefault();
                
                db.Connection.Close();

                return query;
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }         
        }
    }
}
