﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Dades;
using System.Windows.Forms;

namespace Negoci
{
    // Classe que agrupa la lògica de l'aplicació relativa a les operacions amb reserves.
    public class Reserva
    {
        // Establim la connexió amb les classes que modelitzen la BD.
        DataClassesDataContext db = new DataClassesDataContext();

        // Mètode que retorna una reserva segons el seu identificador.
        public Reserves getReserva(int id)
        {
            try
            {
                var query = (from c in db.Reserves
                             where c.idReserva == id
                             select c).FirstOrDefault();
                return query;
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }
        }

        // Mètode que permet afegir una reserva al sistema.
        public string AfegirReserva(string DNI, DateTime data, TimeSpan hora, int comensals, string comentaris)
        {
            try
            {
                DateTime avui = new DateTime();
                avui = DateTime.Today;

                // Només s'acceptem reserves per dies posteriors a avui.
                if (data.CompareTo(avui.Date) <= 0) return "Només es poden fer reserves per dates posteriors a la d'avui";

                // Es comprova si el client ja té una oferta per aquest dia
                foreach (Reserves r in ReservesClient(DNI))
                {
                    bool trobat = false;
                    trobat = (r.data.Equals(data));
                    if (trobat) return "Ja té una reserva per aquesta data";
                }

                // Es comprova si hi ha places disponibles per fer la reserva.
                if (!this.ConsultarDisponibilitat(data, hora, comensals))
                {
                    return "No hi ha places disponibles per aquest dia i aquesta hora";
                }

                // Si la reserva ha superat les restriccions prèvies, s'enregistra al sistema.
                else
                {
                    Reserves r = new Reserves();

                    r.DNIClient = int.Parse(DNI);

                    r.data = data;

                    r.hora = hora;

                    r.numComensals = comensals;

                    r.comentaris = comentaris;

                    db.Reserves.InsertOnSubmit(r);

                    db.SubmitChanges();

                    return "S'ha efectuat la reserva";
                }
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }
        }

        // Mètode que permet saber si hi ha places disponibles al restaurant un dia, una hora i per un nombre de comensals.
        // Per fer-ho, suposem que el restaurant té 12 taules de 4 comensals cadascuna.
        public Boolean ConsultarDisponibilitat(DateTime data, TimeSpan hora, int comensals)
        {
            try
            {
            int taulesOcupades = 0;

            Boolean resultat = false;
           
                // Mirem a la BD les reserves enregistrades per aquest dia i per l'hora (sencera).
                var query = (from q in db.Reserves
                             where q.data.Date.Equals(data.Date) && q.hora.Hours.Equals(hora.Hours)
                             select q);

                // Recorrem el resultat de la consulta i anem calculant quantes taules hi haurà ocupades tenint en compte
                // que cada reserva ocupa, com a mínim, una taula, encara que no l'ompli.
                if (query.Count() > 0)
                    foreach (Reserves q in query)
                    {
                        taulesOcupades += ((q.numComensals + 3) / 4);
                    }

                // En funció de les taules que ja hi ha ocupades i de les que necessitem per a la nova reserva, decidim.           
                taulesOcupades += ((comensals + 3) / 4);

                // Si s'ocupen menys taules de les disponibles (12) hi ha disponibilitat.
                if (taulesOcupades.CompareTo(13) < 0) { resultat = true; }

                // Si no, no hi ha disponibilitat.
                else { resultat = false; }

                return resultat;                
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return false; }           
        }

        // Mètode que retorna les reserves fetes pel client amb el DNI donat.
        public List<Reserves> ReservesClient(string DNI)
        {
            try
            {
                var query = (from q in db.Reserves
                           where q.DNIClient.Equals(DNI)
                           select q).ToList();

                return query;                
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return null; }                       
        }

        // Mètode que permet esborrar la reserva amb l'identificador donat.
        public Boolean EsborrarReserva(int id)
        {
            try
            {
                var query = (from q in db.Reserves
                             where q.idReserva == id
                             select q).FirstOrDefault();

                db.Reserves.DeleteOnSubmit(query);

                db.SubmitChanges();

                return true;
            }
            catch (Exception ex) { MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); return false; }                       
        }
    }
}
